@@ -12,7 +12,7 @@ use Data::Object::Class;
 
 extends 'FlightRecorder::Plugin::Report';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 # METHODS
 
@@ -97,6 +97,14 @@ L<FlightRecorder::Plugin::Report>
 
 =cut
 
+=head1 LIBRARIES
+
+This package uses type constraints from:
+
+L<Types::Standard>
+
+=cut
+
 =head1 ATTRIBUTES
 
 This package has the following attributes:
